ctyped documentation
====================
https://github.com/idlesign/ctyped



Description
-----------

*Build ctypes interfaces for shared libraries with type hinting*

**Requires Python 3.6+**

* Less boilerplate;
* Logical structuring;
* Useful helpers.


Requirements
------------

1. Python 3.6+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    library
